==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebColumnResizeEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnResizeEventArgsDetailDescription } from "./WebColumnResizeEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnResizeEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnResizeEventArgsDetailDescriptionMetadata, _super);
    function WebColumnResizeEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnResizeEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnResizeEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnResizeEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnResizeEventArgsDetailDescriptionMetadata.c(WebColumnResizeEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnResizeEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebColumnResizeEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnResizeEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnResizeEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Column", "ExportedType:WebColumn");
        a.item("PrevWidth", "String");
        a.item("NewWidth", "String");
    };
    WebColumnResizeEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnResizeEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebColumnResizeEventArgsDetail", function () { return new WebColumnResizeEventArgsDetailDescription(); });
        a.ac("WebColumnResizeEventArgsDetail", WebColumnResizeEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnResizeEventArgsDetailDescriptionMetadata.$t = markType(WebColumnResizeEventArgsDetailDescriptionMetadata, 'WebColumnResizeEventArgsDetailDescriptionMetadata');
    WebColumnResizeEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnResizeEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnResizeEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebColumnResizeEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnResizeEventArgsDetailDescription } from "./WebColumnResizeEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnResizeEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnResizeEventArgsDetailDescriptionMetadata, _super);
    function WebColumnResizeEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnResizeEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnResizeEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnResizeEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnResizeEventArgsDetailDescriptionMetadata.c(WebColumnResizeEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnResizeEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebColumnResizeEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnResizeEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnResizeEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Column", "ExportedType:WebColumn");
        a.item("PrevWidth", "String");
        a.item("NewWidth", "String");
    };
    WebColumnResizeEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnResizeEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebColumnResizeEventArgsDetail", function () { return new WebColumnResizeEventArgsDetailDescription(); });
        a.ad("WebColumnResizeEventArgsDetail", WebColumnResizeEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnResizeEventArgsDetailDescriptionMetadata.$t = markType(WebColumnResizeEventArgsDetailDescriptionMetadata, 'WebColumnResizeEventArgsDetailDescriptionMetadata');
    WebColumnResizeEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnResizeEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnResizeEventArgsDetailDescriptionMetadata };
